/*
 * DB-ALLe - Archive for punctual meteorological data
 *
 * Copyright (C) 2005,2006  ARPA-SIM <urpsim@smr.arpa.emr.it>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 *
 * Author: Enrico Zini <enrico@enricozini.com>
 */

#include "init.h"
#include "config.h"

#ifdef HAVE_DBALLE_BUFREX
void bufrex_codec_init(void);
void bufrex_codec_shutdown(void);
#endif
#ifdef HAVE_DBALLE_MSG
void aof_codec_init(void);
void aof_codec_shutdown(void);
#endif

void dba_init()
{
#ifdef HAVE_DBALLE_BUFREX
	bufrex_codec_init();
#endif
#ifdef HAVE_DBALLE_MSG
	aof_codec_init();
#endif
}

void dba_shutdown()
{
#ifdef HAVE_DBALLE_BUFREX
	bufrex_codec_shutdown();
#endif
#ifdef HAVE_DBALLE_MSG
	aof_codec_shutdown();
#endif
}

/* vim:set ts=4 sw=4: */
